package Sah::SchemaR::num_seq;

our $DATE = '2021-07-17'; # DATE
our $VERSION = '0.001'; # VERSION

our $rschema = ["str",[{examples=>[{data=>"",summary=>"Empty string",valid=>0},{data=>"1,2,",summary=>"invalid syntax",valid=>0},{data=>"1,2,3",valid=>1},{data=>"1,2,3,...",valid=>1},{data=>"1,2,3,...,10",valid=>1},{data=>"1,2,3,...,Inf",valid=>1}],match=>qr(\A
                (?:[+-]?[0-9]+(?:\.[0-9]+)?)
                (?:
                    \s*,\s*
                    (?:[+-]?[0-9]+(?:\.[0-9]+)?)
                )*
                (?:
                    \s*,\s*
                    \.\.\.
                )?
                (?:
                    \s*,\s*
                    (?:
                        (?:[+-]?[0-9]+(?:\.[0-9]+)?) | [+-]?Inf
                    )
                )?
                \z)x,prefilters=>["NumSeq::check_num_seq"],summary=>"Number sequence, e.g. 1,3,5,...,16"}],["str"]];

1;
# ABSTRACT: Number sequence, e.g. 1,3,5,...,16

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::num_seq - Number sequence, e.g. 1,3,5,...,16

=head1 VERSION

This document describes version 0.001 of Sah::SchemaR::num_seq (from Perl distribution Sah-Schemas-NumSeq), released on 2021-07-17.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-NumSeq>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-NumSeq>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-NumSeq>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
